###############################################################################
#
#  Welcome to Baml! To use this generated code, please run the following:
#
#  $ pip install baml
#
###############################################################################

# This file was generated by BAML: please do not edit it. Instead, edit the
# BAML files and re-generate this code.
#
# ruff: noqa: E501,F401
# flake8: noqa: E501,F401
# pylint: disable=unused-import,line-too-long
# fmt: off
from typing import Any, Dict, List, Optional, TypeVar, Union, TypedDict, Type
from typing_extensions import NotRequired
import pprint

import baml_py
from pydantic import BaseModel, ValidationError, create_model

from . import partial_types, types
from .type_builder import TypeBuilder
from .globals import DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_CTX, DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_RUNTIME


OutputType = TypeVar('OutputType')

def coerce(cls: Type[BaseModel], parsed: Any) -> Any:
  try:
    return cls.model_validate({"inner": parsed}).inner # type: ignore
  except ValidationError as e:
    raise TypeError(
      "Internal BAML error while casting output to {}\n{}".format(
        cls.__name__,
        pprint.pformat(parsed)
      )
    ) from e

# Define the TypedDict with optional parameters having default values
class BamlCallOptions(TypedDict, total=False):
    tb: NotRequired[TypeBuilder]
    client_registry: NotRequired[baml_py.baml_py.ClientRegistry]

class BamlAsyncClient:
    __runtime: baml_py.BamlRuntime
    __ctx_manager: baml_py.BamlCtxManager
    __stream_client: "BamlStreamClient"

    def __init__(self, runtime: baml_py.BamlRuntime, ctx_manager: baml_py.BamlCtxManager):
      self.__runtime = runtime
      self.__ctx_manager = ctx_manager
      self.__stream_client = BamlStreamClient(self.__runtime, self.__ctx_manager)

    @property
    def stream(self):
      return self.__stream_client


    
    async def ChangePlan(
        self,
        screenshot: baml_py.Image,changes: str,old_plan: List[types.PlanningStep],
        baml_options: BamlCallOptions = {},
    ) -> List[types.PlanningStep]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = await self.__runtime.call_function(
        "ChangePlan",
        {
          "screenshot": screenshot,"changes": changes,"old_plan": old_plan,
        },
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )
      mdl = create_model("ChangePlanReturnType", inner=(List[types.PlanningStep], ...))
      return coerce(mdl, raw.parsed())
    
    async def CreatePlan(
        self,
        screenshot: baml_py.Image,task_instructions: str,old_plan: List[types.PlanningStep],
        baml_options: BamlCallOptions = {},
    ) -> List[types.PlanningStep]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = await self.__runtime.call_function(
        "CreatePlan",
        {
          "screenshot": screenshot,"task_instructions": task_instructions,"old_plan": old_plan,
        },
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )
      mdl = create_model("CreatePlanReturnType", inner=(List[types.PlanningStep], ...))
      return coerce(mdl, raw.parsed())
    
    async def DetermineSelectorStyle(
        self,
        instructions: str,target: types.Element,next_sibling: Optional[types.Element],previous_sibling: Optional[types.Element],ancestors: str,
        baml_options: BamlCallOptions = {},
    ) -> List[types.SelectorStyle]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = await self.__runtime.call_function(
        "DetermineSelectorStyle",
        {
          "instructions": instructions,"target": target,"next_sibling": next_sibling,"previous_sibling": previous_sibling,"ancestors": ancestors,
        },
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )
      mdl = create_model("DetermineSelectorStyleReturnType", inner=(List[types.SelectorStyle], ...))
      return coerce(mdl, raw.parsed())
    
    async def ElementsPerStep(
        self,
        plan: str,current_step: types.PlanningStep,
        baml_options: BamlCallOptions = {},
    ) -> List[str]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = await self.__runtime.call_function(
        "ElementsPerStep",
        {
          "plan": plan,"current_step": current_step,
        },
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )
      mdl = create_model("ElementsPerStepReturnType", inner=(List[str], ...))
      return coerce(mdl, raw.parsed())
    
    async def GeneratePlaywrightCode(
        self,
        procedure_name: str,procedure_steps: List[types.Step],
        baml_options: BamlCallOptions = {},
    ) -> str:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = await self.__runtime.call_function(
        "GeneratePlaywrightCode",
        {
          "procedure_name": procedure_name,"procedure_steps": procedure_steps,
        },
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )
      mdl = create_model("GeneratePlaywrightCodeReturnType", inner=(str, ...))
      return coerce(mdl, raw.parsed())
    
    async def GenerateXPathSelector(
        self,
        instructions: str,target: types.Element,ancestors: str,next_sibling: Optional[types.Element],previous_sibling: Optional[types.Element],selector_styles: List[types.SelectorStyle],
        baml_options: BamlCallOptions = {},
    ) -> List[str]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = await self.__runtime.call_function(
        "GenerateXPathSelector",
        {
          "instructions": instructions,"target": target,"ancestors": ancestors,"next_sibling": next_sibling,"previous_sibling": previous_sibling,"selector_styles": selector_styles,
        },
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )
      mdl = create_model("GenerateXPathSelectorReturnType", inner=(List[str], ...))
      return coerce(mdl, raw.parsed())
    


class BamlStreamClient:
    __runtime: baml_py.BamlRuntime
    __ctx_manager: baml_py.BamlCtxManager

    def __init__(self, runtime: baml_py.BamlRuntime, ctx_manager: baml_py.BamlCtxManager):
      self.__runtime = runtime
      self.__ctx_manager = ctx_manager

    
    def ChangePlan(
        self,
        screenshot: baml_py.Image,changes: str,old_plan: List[types.PlanningStep],
        baml_options: BamlCallOptions = {},
    ) -> baml_py.BamlStream[List[partial_types.PlanningStep], List[types.PlanningStep]]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = self.__runtime.stream_function(
        "ChangePlan",
        {
          "screenshot": screenshot,
          "changes": changes,
          "old_plan": old_plan,
        },
        None,
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )

      mdl = create_model("ChangePlanReturnType", inner=(List[types.PlanningStep], ...))
      partial_mdl = create_model("ChangePlanPartialReturnType", inner=(List[partial_types.PlanningStep], ...))

      return baml_py.BamlStream[List[partial_types.PlanningStep], List[types.PlanningStep]](
        raw,
        lambda x: coerce(partial_mdl, x),
        lambda x: coerce(mdl, x),
        self.__ctx_manager.get(),
      )
    
    def CreatePlan(
        self,
        screenshot: baml_py.Image,task_instructions: str,old_plan: List[types.PlanningStep],
        baml_options: BamlCallOptions = {},
    ) -> baml_py.BamlStream[List[partial_types.PlanningStep], List[types.PlanningStep]]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = self.__runtime.stream_function(
        "CreatePlan",
        {
          "screenshot": screenshot,
          "task_instructions": task_instructions,
          "old_plan": old_plan,
        },
        None,
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )

      mdl = create_model("CreatePlanReturnType", inner=(List[types.PlanningStep], ...))
      partial_mdl = create_model("CreatePlanPartialReturnType", inner=(List[partial_types.PlanningStep], ...))

      return baml_py.BamlStream[List[partial_types.PlanningStep], List[types.PlanningStep]](
        raw,
        lambda x: coerce(partial_mdl, x),
        lambda x: coerce(mdl, x),
        self.__ctx_manager.get(),
      )
    
    def DetermineSelectorStyle(
        self,
        instructions: str,target: types.Element,next_sibling: Optional[types.Element],previous_sibling: Optional[types.Element],ancestors: str,
        baml_options: BamlCallOptions = {},
    ) -> baml_py.BamlStream[List[Optional[types.SelectorStyle]], List[types.SelectorStyle]]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = self.__runtime.stream_function(
        "DetermineSelectorStyle",
        {
          "instructions": instructions,
          "target": target,
          "next_sibling": next_sibling,
          "previous_sibling": previous_sibling,
          "ancestors": ancestors,
        },
        None,
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )

      mdl = create_model("DetermineSelectorStyleReturnType", inner=(List[types.SelectorStyle], ...))
      partial_mdl = create_model("DetermineSelectorStylePartialReturnType", inner=(List[Optional[types.SelectorStyle]], ...))

      return baml_py.BamlStream[List[Optional[types.SelectorStyle]], List[types.SelectorStyle]](
        raw,
        lambda x: coerce(partial_mdl, x),
        lambda x: coerce(mdl, x),
        self.__ctx_manager.get(),
      )
    
    def ElementsPerStep(
        self,
        plan: str,current_step: types.PlanningStep,
        baml_options: BamlCallOptions = {},
    ) -> baml_py.BamlStream[List[Optional[str]], List[str]]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = self.__runtime.stream_function(
        "ElementsPerStep",
        {
          "plan": plan,
          "current_step": current_step,
        },
        None,
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )

      mdl = create_model("ElementsPerStepReturnType", inner=(List[str], ...))
      partial_mdl = create_model("ElementsPerStepPartialReturnType", inner=(List[Optional[str]], ...))

      return baml_py.BamlStream[List[Optional[str]], List[str]](
        raw,
        lambda x: coerce(partial_mdl, x),
        lambda x: coerce(mdl, x),
        self.__ctx_manager.get(),
      )
    
    def GeneratePlaywrightCode(
        self,
        procedure_name: str,procedure_steps: List[types.Step],
        baml_options: BamlCallOptions = {},
    ) -> baml_py.BamlStream[Optional[str], str]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = self.__runtime.stream_function(
        "GeneratePlaywrightCode",
        {
          "procedure_name": procedure_name,
          "procedure_steps": procedure_steps,
        },
        None,
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )

      mdl = create_model("GeneratePlaywrightCodeReturnType", inner=(str, ...))
      partial_mdl = create_model("GeneratePlaywrightCodePartialReturnType", inner=(Optional[str], ...))

      return baml_py.BamlStream[Optional[str], str](
        raw,
        lambda x: coerce(partial_mdl, x),
        lambda x: coerce(mdl, x),
        self.__ctx_manager.get(),
      )
    
    def GenerateXPathSelector(
        self,
        instructions: str,target: types.Element,ancestors: str,next_sibling: Optional[types.Element],previous_sibling: Optional[types.Element],selector_styles: List[types.SelectorStyle],
        baml_options: BamlCallOptions = {},
    ) -> baml_py.BamlStream[List[Optional[str]], List[str]]:
      __tb__ = baml_options.get("tb", None)
      if __tb__ is not None:
        tb = __tb__._tb
      else:
        tb = None
      __cr__ = baml_options.get("client_registry", None)

      raw = self.__runtime.stream_function(
        "GenerateXPathSelector",
        {
          "instructions": instructions,
          "target": target,
          "ancestors": ancestors,
          "next_sibling": next_sibling,
          "previous_sibling": previous_sibling,
          "selector_styles": selector_styles,
        },
        None,
        self.__ctx_manager.get(),
        tb,
        __cr__,
      )

      mdl = create_model("GenerateXPathSelectorReturnType", inner=(List[str], ...))
      partial_mdl = create_model("GenerateXPathSelectorPartialReturnType", inner=(List[Optional[str]], ...))

      return baml_py.BamlStream[List[Optional[str]], List[str]](
        raw,
        lambda x: coerce(partial_mdl, x),
        lambda x: coerce(mdl, x),
        self.__ctx_manager.get(),
      )
    

b = BamlAsyncClient(DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_RUNTIME, DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_CTX)

__all__ = ["b"]


###############################################################################
#
#  Welcome to Baml! To use this generated code, please run the following:
#
#  $ pip install baml
#
###############################################################################

# This file was generated by BAML: please do not edit it. Instead, edit the
# BAML files and re-generate this code.
#
# ruff: noqa: E501,F401
# flake8: noqa: E501,F401
# pylint: disable=unused-import,line-too-long
# fmt: off
import os

from baml_py import BamlCtxManager, BamlRuntime
from baml_py.baml_py import BamlError
from .inlinedbaml import get_baml_files
from typing import Dict

DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_RUNTIME = BamlRuntime.from_files(
  "baml_src",
  get_baml_files(),
  os.environ.copy()
)
DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_CTX = BamlCtxManager(DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_RUNTIME)

def reset_baml_env_vars(env_vars: Dict[str, str]):
  if DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_CTX.allow_reset():
    DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_RUNTIME.reset(
      "baml_src",
      get_baml_files(),
      env_vars
    )
    DO_NOT_USE_DIRECTLY_UNLESS_YOU_KNOW_WHAT_YOURE_DOING_CTX.reset()
  else:
    raise BamlError("Cannot reset BAML environment variables while there are active BAML contexts.")

__all__ = []


###############################################################################
#
#  Welcome to Baml! To use this generated code, please run the following:
#
#  $ pip install baml
#
###############################################################################

# This file was generated by BAML: please do not edit it. Instead, edit the
# BAML files and re-generate this code.
#
# ruff: noqa: E501,F401
# flake8: noqa: E501,F401
# pylint: disable=unused-import,line-too-long
# fmt: off

file_map = {
    
    "clients.baml": "// Learn more about clients at https://docs.boundaryml.com/docs/snippets/clients/overview",
    "codegen.baml": "class Attribute {\n  name string\n  value string\n}\n\nclass Element {\n  tagName string\n  textContent string?\n  attributes Attribute[]\n}\n\nclass Step {\n  step_index int\n  selector string\n  instructions string\n}\n\nenum SelectorStyle {\n  ID_BASED @description(\"Use the element's id, data-id, or name attribute\")\n  CLASS_BASED @description(\"Use the element's class attribute\")\n  PATH_BASED @description(\"Use the path between the element and its ancestors\")\n  INNER_TEXT_BASED @description(\"Use the element or its children's inner text\")\n  LABEL_BASED @description(\"Use nearby static text or label elements\")\n  SIBLING_BASED @description(\"Use the element's next or previous sibling's tag, text, or attribute\")\n  HREF_BASED @description(\"Use the element's href attribute\")\n  STYLE_BASED @description(\"Use the element's style attribute\")\n  OTHER_ATTRIBUTE_BASED @description(\"Use the element's other attributes\")\n}\n\ntemplate_string FinicAPIReference() #\"\n  class Finic:\n    \"\"\"\n    Finic class for browser automation and interaction.\n    \n    Attributes:\n        api_key (Optional[str]): API key for authentication.\n        env (Optional[FinicEnvironment]): Environment setting (LOCAL or PROD).\n        context_storage_path (Optional[str]): Path to store browser context, default is \"storage_state.json\".\n    \"\"\"\n\n    def __init__(self, api_key: Optional[str] = None, environment: Optional[FinicEnvironment] = None):\n        \"\"\"\n        Initialize a new Finic instance.\n\n        Args:\n            api_key (Optional[str]): API key for authentication. If not provided, tries to get from environment variable.\n            environment (Optional[FinicEnvironment]): Environment setting. If not provided, uses FINIC_ENV environment variable or defaults to LOCAL.\n        \"\"\"\n        # Implementation details...\n\n    def save_context(self, context: BrowserContext, path: Optional[str] = None) -> None:\n        \"\"\"\n        Save the current browser context to a file.\n\n        Args:\n            context (BrowserContext): The browser context to save.\n            path (Optional[str]): The path to save the context. If not provided, uses the default path.\n        \"\"\"\n        # Implementation omitted...\n\n    def screenshot(self, page: Union[Page, AsyncPage], selector: str, path: str) -> None:\n        \"\"\"\n        Take a screenshot of a specific element on the page.\n\n        Args:\n            page (Union[Page, AsyncPage]): The page object to screenshot.\n            selector (str): The selector for the element to screenshot.\n            path (str): The file path to save the screenshot.\n        \"\"\"\n        # Implementation omitted...\n\n    @classmethod\n    def procedure(cls, func: Callable) -> Callable:\n        \"\"\"\n        Decorator for procedure functions. Ensures the first argument is a Page object and the return value is a Page object.\n\n        Args:\n            func (Callable): The function to wrap.\n\n        Returns:\n            Callable: Wrapped function.\n        \"\"\"\n        # Implementation omitted...\n\n\"#\n\nfunction DetermineSelectorStyle(instructions: string, target: Element, next_sibling: Element?, previous_sibling: Element?, ancestors: string) -> SelectorStyle[] {\n  client \"anthropic/claude-3-5-sonnet-20240620\"\n  prompt #\"\n    Determine the best way to create an XPath selector for the provided HTML element, based on the instructions provided by the user\n    as well as its ancestors{% if next_sibling or previous_sibling %} and siblings{% endif %}. Consider whether the element's attributes are unique, whether it has a discernible label, \n    and whether the text of the element or its children can be used to uniquely identify it. Return in order of preference, from\n    most preferred to least preferred.\n\n    User Instructions: {{ instructions }}\n\n    Target Element:\n    {{ target }}\n\n    {% if next_sibling %}\n    Next Sibling:\n    {{ next_sibling }}\n    {% endif %}\n\n    {% if previous_sibling %}\n    Previous Sibling:\n    {{ previous_sibling }}\n    {% endif %}\n\n    Ancestors:\n    {{ ancestors }}\n\n    {{ ctx.output_format }}\n  \"#\n}\n\n// Generate a selector for a given HTML element.\nfunction GenerateXPathSelector(instructions: string, target: Element, ancestors: string, next_sibling: Element?, previous_sibling: Element?, selector_styles: SelectorStyle[]) -> string[] {\n  client \"anthropic/claude-3-5-sonnet-20240620\"\n  prompt #\"\n    Generate three XPath selectors based on the provided HTML tag and the user's instructions. Return them in order of confidence.\n\n    User Instructions: {{ instructions }}\n\n    Adhere to the following guidelines when determining the best XPath:\n    {% for selector_style in selector_styles %}\n    {% if selector_style == \"OTHER_ATTRIBUTE_BASED\" %}\n    - Consider the tag's attributes\n    {% elif selector_style == \"ID_BASED\" %}\n    - Consider the tag's id attribute\n    {% elif selector_style == \"CLASS_BASED\" %}\n    - Consider the tag's class attribute\n    {% elif selector_style == \"PATH_BASED\" %}\n    - Consider the path between the tag and its ancestors\n    {% elif selector_style == \"INNER_TEXT_BASED\" %}\n    - Consider the tag's inner text. Use normalize-space(string(.) || string(*)) to get the text content.\n    {% elif selector_style == \"LABEL_BASED\" %}\n    - Consider nearby static text or label elements\n    {% endif %}\n    {% if selector_style == \"HREF_BASED\" %}\n    - Consider the tag's href attribute\n    {% endif %}\n    {% if selector_style == \"STYLE_BASED\" %}\n    - Consider the tag's style attribute\n    {% endif %}\n    {% endfor %}\n\n    Target Tag:\n    {{ target }}\n\n    {% if next_sibling %}\n    Next Sibling:\n    {{ next_sibling }}\n    {% endif %}\n\n    {% if previous_sibling %}\n    Previous Sibling:\n    {{ previous_sibling }}\n    {% endif %}\n\n    {% if ancestors %}\n    Ancestors:\n    {{ ancestors }}\n    {% endif %}\n\n    {{ ctx.output_format }}\n  \"#\n}\n\nfunction GeneratePlaywrightCode(procedure_name: string, procedure_steps: Step[]) -> string {\n  client \"anthropic/claude-3-5-sonnet-20240620\"\n  prompt #\"\n    Given a list of steps for a procedure for automation actions in a web browser, \n    complete the python function below.\n\n    Procedure Steps: \n    {{ procedure_steps }}\n\n    Make sure to provide your response as a markdown code block and start your response as follows:\n    ```python\n    from playwright.sync_api import Page\n    from finic import Finic\n\n    @Finic.procedure\n    def {{ procedure_name }}(page: Page):\n\n    {{ ctx.output_format }}\n  \"#\n}",
    "copilot.baml": "class PlanningStep {\n  step_number int\n  description string\n}\n\ntemplate_string AskForElements(elements: string[]) #\"\n  Please click on the elements\n\n\n\"#\n\nfunction CreatePlan(screenshot: image, task_instructions: string, old_plan: PlanningStep[]) -> PlanningStep[] {\n  client \"anthropic/claude-3-5-sonnet-20240620\"\n  prompt #\"\n    Come up with a detailed, step by step plan for how to perform a browser-based automation task, based on a screenshot\n    of a web page and the instructions provided by the user. The plan should describe each element that needs to be interacted\n    with and the actions to be taken on each element.\n    \n    The technology stack is Python with Playwright.\n\n    Examples of steps: \n    - Expand the \"Flights\" drawer\n    - Click the \"Search\" input and enter \"Finic\"\n    - Select the \"Offline\" radio button\n    \n    Current page:\n    {{ screenshot }}\n\n    Instructions: {{ task_instructions }}\n\n    {{ ctx.output_format }}\n  \"#\n}\n\nfunction ChangePlan(screenshot: image, changes: string, old_plan: PlanningStep[]) -> PlanningStep[] {\n  client \"anthropic/claude-3-5-sonnet-20240620\"\n  prompt #\"\n    Given the current plan and proposed changes, come up with a revised plan for how to perform a browser-based automation task.\n\n    Current page:\n    {{ screenshot }}\n\n    Current plan:\n    {% for step in old_plan %}\n    {{ step.step_number }}. {{ step.description }}\n    {% endfor %}\n\n    Proposed changes: {{ changes }}\n\n    {{ ctx.output_format }}\n  \"#\n}\n\nfunction ElementsPerStep(plan: string, current_step: PlanningStep) -> string[] {\n  client \"anthropic/claude-3-5-sonnet-20240620\"\n  prompt #\"\n    Given the current plan and the step we're on, return a list of elements visible on the page for which we'll need selectors in order to perform the step.\n    You do not know the HTML structure of the page yet, so elements should be returned as a list of string descriptions for the user so they can identify them.\n\n    Examples of of outputs:\n    - \"Flights\" drawer\n    - \"Search\" input\n    - \"Offline\" radio button\n    - Text component containing flight details\n\n    Current plan:\n    {{ plan }}\n\n    Current step:\n    {{ current_step }}\n\n    {{ ctx.output_format }}\n  \"#\n}",
    "generators.baml": "// This helps use auto generate libraries you can use in the language of\n// your choice. You can have multiple generators if you use multiple languages.\n// Just ensure that the output_dir is different for each generator.\ngenerator target {\n    // Valid values: \"python/pydantic\", \"typescript\", \"ruby/sorbet\", \"rest/openapi\"\n    output_type \"python/pydantic\"\n\n    // Where the generated code will be saved (relative to baml_src/)\n    output_dir \"../\"\n\n    // The version of the BAML package you have installed (e.g. same version as your baml-py or @boundaryml/baml).\n    // The BAML VSCode extension version should also match this version.\n    version \"0.58.0\"\n\n    // Valid values: \"sync\", \"async\"\n    // This controls what `b.FunctionName()` will be (sync or async).\n    default_client_mode sync\n}\n",
}

def get_baml_files():
    return file_map